import time
from .utils import make_request
from .exceptions import CandleAIError, AuthenticationError, RateLimitError, ConnectionError, APIError


class CandleAIClient:
    """
    Клиент для работы с CandleAI API
    """

    def __init__(self, base_url, api_key):
        self.base_url = base_url.rstrip('/')
        self.api_key = api_key
        self.user_id = f"user_{int(time.time())}"
        self._headers = {
            "X-API-Key": self.api_key,
            "Content-Type": "application/json"
        }

    def chat(self, message, user_id=None):
        """
        Отправляет сообщение ИИ и получает ответ
        """
        data = {
            "message": message,
            "user_id": user_id or self.user_id
        }

        return make_request(
            method="POST",
            url=f"{self.base_url}/chat",
            headers=self._headers,
            json_data=data
        )

    def get_server_info(self):
        """
        Получает информацию о сервере
        """
        return make_request(
            method="GET",
            url=f"{self.base_url}/info",
            headers=self._headers
        )

    def health_check(self):
        """
        Проверяет статус сервера
        """
        return make_request(
            method="GET",
            url=f"{self.base_url}/health"
        )

    def get_facts(self):
        """
        Получает список доступных фактов
        """
        return make_request(
            method="GET",
            url=f"{self.base_url}/facts"
        )


import requests
from .exceptions import AuthenticationError, RateLimitError, ConnectionError, APIError


def make_request(method, url, headers=None, json_data=None, timeout=30):
    """Универсальная функция для HTTP запросов"""
    try:
        response = requests.request(
            method=method,
            url=url,
            headers=headers,
            json=json_data,
            timeout=timeout
        )

        if response.status_code == 401:
            raise AuthenticationError("Неверный API ключ")
        elif response.status_code == 429:
            raise RateLimitError("Лимит скриптов исчерпан")
        elif response.status_code >= 400:
            raise APIError(f"Ошибка API: {response.status_code} - {response.text}")

        return response.json()

    except requests.exceptions.ConnectionError:
        raise ConnectionError("Не удалось подключиться к серверу")
    except requests.exceptions.Timeout:
        raise ConnectionError("Превышено время ожидания")
    except requests.exceptions.RequestException as e:
        raise ConnectionError(f"Ошибка сети: {e}")


class CandleAIError(Exception):
    """Базовое исключение для CandleAI"""
    pass

class AuthenticationError(CandleAIError):
    """Ошибка аутентификации (неверный API ключ)"""
    pass

class RateLimitError(CandleAIError):
    """Превышен лимит запросов"""
    pass

class ConnectionError(CandleAIError):
    """Ошибка подключения к серверу"""
    pass

class APIError(CandleAIError):
    """Ошибка API сервера"""
    pass


"""
CandleAI Python Client
Универсальный клиент для CandleAI API
"""

__version__ = "1.0.0"
__author__ = "Your Name"
__email__ = "your.email@example.com"

# Импортируем все необходимое
from .client import CandleAIClient
from .exceptions import (
    CandleAIError,
    AuthenticationError,
    RateLimitError,
    ConnectionError,
    APIError
)

# Определяем что импортировать при from candleai import *
__all__ = [
    'CandleAIClient',
    'CandleAIError',
    'AuthenticationError',
    'RateLimitError',
    'ConnectionError',
    'APIError'
]


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="candleai",
    version="1.0.0",
    author="Your Name",
    author_email="your.email@example.com",
    description="Python клиент для CandleAI API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[
        "requests>=2.25.0"
    ],
    python_requires=">=3.7",
    keywords="ai, chatbot, api, candleai",
)